@@ -14,6 +14,7 @@ from suite_py.commands import project_lock
 from suite_py.commands import ask_review
 from suite_py.commands import create_qa
 from suite_py.commands import delete_qa
+from suite_py.commands import status
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.config import Config
 from suite_py.__version__ import __version__
@@ -122,3 +123,9 @@ def cli_deploy(ctx):
 @click.pass_context
 def cli_rollback(ctx):
     rollback.entrypoint(ctx.obj["project"])
+
+
+@main.command("status", help="Stato attuale di un progetto")
+@click.pass_context
+def cli_status(ctx):
+    status.entrypoint(ctx.obj["project"], ctx.obj["captainhook_timeout"])
