@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-import os
-import re
 import sys
 
+from halo import Halo
+
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.handler.github_handler import GithubHandler
 from suite_py.lib.handler.captainhook_handler import CaptainHook
@@ -17,7 +17,10 @@ from suite_py.lib.handler import drone_handler as drone
 youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
-config = Config().load()
+config = Config()
+
+CHECKMARK = "✔"
+CROSSMARK = "✘"
 
 
 def entrypoint(project, timeout):
@@ -36,7 +39,10 @@ def entrypoint(project, timeout):
     logger.info("Eseguo il merge...")
 
     merge_status = pr.merge(
-        commit_title="{} (#{})".format(pr.title, pr.number), commit_message='', merge_method='squash')
+        commit_title=f"{pr.title} (#{pr.number})",
+        commit_message="",
+        merge_method="squash",
+    )
 
     if not merge_status.merged:
         logger.error("Si è verificato un errore durante il merge.")
@@ -46,7 +52,8 @@ def entrypoint(project, timeout):
 
     if drone_build:
         logger.info(
-            "Pull request mergiata su master! Puoi seguire lo stato della build su {}".format(drone_build))
+            f"Pull request mergiata su master! Puoi seguire lo stato della build su {drone_build}"
+        )
     else:
         logger.info("Pull request mergiata su master!")
 
@@ -54,21 +61,26 @@ def entrypoint(project, timeout):
     if git.remote_branch_exists(project, branch_name):
         git.delete_remote_branch(project, branch_name)
 
-    if prompt_utils.ask_confirm("Vuoi bloccare staging? (Necessario se bisogna testare su staging)", default=False):
+    if prompt_utils.ask_confirm(
+        "Vuoi bloccare staging? (Necessario se bisogna testare su staging)",
+        default=False,
+    ):
         lock.lock_project(project)
 
     if youtrack_id:
         logger.info("Aggiorno lo stato della card su youtrack...")
-        youtrack.update_state(youtrack_id, config["youtrack"]["merged_state"])
+        youtrack.update_state(youtrack_id, config.load()["youtrack"]["merged_state"])
         logger.info("Card aggiornata")
 
         logger.info("Spengo il qa, se esiste")
         qainit_shutdown(youtrack_id)
     else:
         logger.warning(
-            "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste.")
+            "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste."
+        )
         logger.warning(
-            "Nessuna card aggiornata su YouTrack e nessun QA spento in automatico")
+            "Nessuna card aggiornata su YouTrack e nessun QA spento in automatico"
+        )
 
     logger.info("Tutto fatto!")
     sys.exit()
@@ -76,29 +88,29 @@ def entrypoint(project, timeout):
 
 def select_pr(project):
     if github.user_is_admin(project):
-        logger.info("Ottengo le pull request da GitHub...")
         logger.warning(
-            "Sei admin del repository, puoi fare il merge skippando i check (CI, review, ecc...)\nDa grandi poteri derivano grandi responsabilita'")
-        prs = github.get_list_pr(project)
-    else:
-        logger.info("Ottengo le pull request con check verdi da GitHub...")
-        prs = list(filter(lambda pr: pr.mergeable and pr.mergeable_state ==
-                          "clean", github.get_list_pr(project)))
+            "Sei admin del repository, puoi fare il merge skippando i check (CI, review, ecc...)\nDa grandi poteri derivano grandi responsabilita'"
+        )
 
-    if hasattr(prs, 'totalCount') and prs.totalCount > 0:
-        choices = [{"name": "{} {}".format(
-            i.number, i.title), "value": i} for i in prs]
-        return prompt_utils.ask_choices('Seleziona PR: ', choices)
-    else:
-        logger.error(
-            "Non esistono pull request pronte per il merge o potresti non avere i permessi, per favore controlla su https://github.com/primait/{}/pulls".format(project))
-        sys.exit(-1)
+    with Halo(text="Loading pull requests...", spinner="dots", color="magenta"):
+        choices = [
+            {"name": choice(project, pr), "value": pr}
+            for pr in github.get_list_pr(project)
+            if pr.mergeable
+        ]
+    if choices:
+        return prompt_utils.ask_choices("Seleziona PR: ", choices)
+
+    logger.error(
+        f"Non esistono pull request pronte per il merge o potresti non avere i permessi, per favore controlla su https://github.com/primait/{project}/pulls"
+    )
+    sys.exit(-1)
 
 
 def stop_if_master_locked(project, lock):
     try:
-        request = lock.status(project)
-    except:
+        request = lock.status(project, "staging")
+    except Exception:
         logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
         sys.exit(-1)
 
@@ -106,15 +118,16 @@ def stop_if_master_locked(project, lock):
         logger.error("Impossibile determinare lo stato del lock su master.")
         sys.exit(-1)
 
-    if request.json()["locked"]:
+    request_object = request.json()
+    if request_object["locked"]:
         logger.error(
-            "Il progetto è lockato su master. Impossibile continuare.")
+            f"Il progetto è lockato su staging da {request_object['by']}. Impossibile continuare."
+        )
         sys.exit(-1)
 
 
 def get_drone_build(project, sha):
-    drone_build = drone.get_pr_build_url(
-        project, sha)
+    drone_build = drone.get_pr_build_url(project, sha)
     if drone_build != "":
         return drone_build
     return None
@@ -126,3 +139,26 @@ def check_migrations_merge(pr):
         logger.warning("ATTENZIONE: migrations rilevate nel codice")
         if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
             sys.exit(-1)
+
+
+def choice(project, pr):
+    build_status = CHECKMARK
+    reviews = CHECKMARK
+    if pr.mergeable_state == "blocked":
+        build_status = pr_build_status(project, pr)
+        reviews = pr_reviews(pr)
+
+    return f"#{pr.number} {pr.title}\n     build: {build_status} - reviews: {reviews}\n"
+
+
+def pr_build_status(project, pr):
+    if github.get_build_status(project, pr.head.sha).state == "success":
+        return CHECKMARK
+    return CROSSMARK
+
+
+def pr_reviews(pr):
+    reviews = [r for r in pr.get_reviews() if r.state == "APPROVED"]
+    if reviews:
+        return CHECKMARK
+    return CROSSMARK
