@@ -1,8 +1,6 @@
 # -*- encoding: utf-8 -*-
-import os
 import re
 
-from PyInquirer import prompt
 from youtrack.connection import Connection
 from youtrack.youtrack import YouTrackException
 
@@ -11,7 +9,10 @@ from suite_py.lib.config import Config
 from suite_py.lib.singleton import Singleton
 
 tokens = Tokens()
-config = Config().load()
+config = Config()
+
+REGEX = r"([A-Z]+-[0-9]+)"
+URL = "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/"
 
 
 class YoutrackHandler(metaclass=Singleton):
@@ -19,7 +20,8 @@ class YoutrackHandler(metaclass=Singleton):
 
     def __init__(self):
         self._client = Connection(
-            url=config['youtrack']['url'], token=tokens.youtrack)
+            url=config.load()["youtrack"]["url"], token=tokens.youtrack
+        )
 
     def get_users(self):
         return self._client.get_users()
@@ -31,23 +33,24 @@ class YoutrackHandler(metaclass=Singleton):
         try:
             if self.get_issue(issue_id):
                 return True
-        except (YouTrackException) as e:
-            return False
+        except YouTrackException:
+            pass
+        return False
 
     def comment(self, issue_id, comment):
-        self._client.execute_command(issue_id, 'comment', comment=comment)
+        self._client.execute_command(issue_id, "comment", comment=comment)
 
     def update_state(self, issue_id, status):
-        self._client.execute_command(issue_id, 'State {}'.format(status))
+        self._client.execute_command(issue_id, f"State {status}")
 
     def add_tag(self, issue_id, label):
-        self._client.execute_command(issue_id, 'tag {}'.format(label))
+        self._client.execute_command(issue_id, f"tag {label}")
 
     def assign_to(self, issue_id, user):
-        self._client.execute_command(issue_id, "Assignee {}".format(user))
+        self._client.execute_command(issue_id, f"Assignee {user}")
 
     def get_link(self, issue_id):
-        return "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/{}".format(issue_id)
+        return f"{URL}{issue_id}"
 
     def update_issue(self, issue_id, summary, description):
         return self._client.update_issue(issue_id, summary, description)
@@ -61,11 +64,11 @@ class YoutrackHandler(metaclass=Singleton):
         return issue_ids
 
     def get_card_from_name(self, name):
-        regex = '[A-Z]+-[0-9]+'
-        if re.search(regex, name):
-            id_card = re.findall(regex, name)[0]
-            if not self.validate_issue(id_card):
-                return None
-            return id_card
-        else:
-            return None
+        if re.search(REGEX, name):
+            id_card = re.findall(REGEX, name)[0]
+            if self.validate_issue(id_card):
+                return id_card
+        return None
+
+    def replace_card_names_with_md_links(self, text):
+        return re.sub(REGEX, f"[\\1]({URL}\\1)", text)
